@@ -87,3 +87,16 @@ def download(target, arg):
     url, dst = arg.split(' ') if ' ' in arg else arg, None
     target.deploy('download', url=url, dst=dst)
 
+def outrun(target, arg):
+    log = target.outrun
+    if log:
+        print(open(log).read())
+    else:
+        print('target outrun not defined')
+
+def outlog(target, arg):
+    log = target.outlog
+    if log:
+        print(open(log).read())
+    else:
+        print('target outlog not defined')
