@@ -20,7 +20,7 @@ def safe(cmd, target):
 
 
 def prompt(target):
-    user = 'sudo' if target.sudo else target.distro.Login.name
+    user = 'sudo' if target.sudo else target.login.name
     return f'{user}@{target.name} > '
 
 
